==> bcc-core-api-node-sdk-1.11.0.tgz: package/lib/esm/test/querying.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { client, getDefaultConfig, personInactiveUid } from "./helpers.js";
import { Affiliation, CoreApiClient, WrappedWithMetaArrayPerson, } from "../api.js";
import { assert } from "chai";
import { ActiveEntity } from "../model/queryParams.js";
describe("Querying", () => __awaiter(void 0, void 0, void 0, function* () {
    let allPersons;
    let clientWithInactiveEntities;
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        allPersons = (yield client.persons.find()).data;
        const defaultConfig = getDefaultConfig();
        defaultConfig.queryOptions = {
            includeInactive: [ActiveEntity.Affiliations, ActiveEntity.Consents],
            includePersonsWithoutChurchAffiliation: true,
        };
        clientWithInactiveEntities = new CoreApiClient(defaultConfig);
    }));
    beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
        yield client.refreshTestData();
    }));
    it("sorting", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            sort: [
                {
                    direction: "ascending",
                    path: "displayName",
                },
            ],
            limit: 2,
            offset: 1,
        });
        assert.equal(result.meta.total, allPersons.length);
        assert.equal(result.meta.skipped, 1);
        assert.equal(result.meta.limit, 2);
        assert.instanceOf(result, WrappedWithMetaArrayPerson);
        const sortedPersons = allPersons.sort((a, b) => a.displayName > b.displayName ? 1 : -1);
        assert.equal(result.data[0].uid, sortedPersons[1].uid);
        assert.equal(result.data[1].uid, sortedPersons[2].uid);
    }));
    it("filtering", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            filter: {
                displayName: {
                    _gte: "Philly Daly",
                },
            },
        });
        const expectedResult = allPersons.filter((p) => p.displayName >= "Philly Daly");
        assert.equal(result.meta.total, expectedResult.length);
    }));
    it("filtering nested", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            filter: {
                affiliations: {
                    person: {
                        displayName: {
                            _eq: "Philly Daly",
                        },
                    },
                },
            },
        });
        const expectedResult = allPersons.filter((p) => p.displayName >= "Philly Daly");
        assert.equal(result.meta.total, expectedResult.length);
    }));
    it("resolving", () => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        const result = yield client.persons.find({
            fields: ["*", "affiliations.*"],
        });
        assert.instanceOf((_a = result.data[0].affiliations) === null || _a === void 0 ? void 0 : _a[0], Affiliation);
    }));
    it("options - include persons without church affiliation", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            options: {
                includePersonsWithoutChurchAffiliation: true,
            },
        });
        const resultUids = result.data.map((r) => r.uid);
        assert.include(resultUids, personInactiveUid);
    }));
    it("options - do not include persons without church affiliation", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            options: {
                includePersonsWithoutChurchAffiliation: false,
            },
        });
        const resultUids = result.data.map((r) => r.uid);
        assert.notInclude(resultUids, personInactiveUid);
    }));
    it("options - include inactive entities", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.affiliations.find({
            options: {
                includeInactive: [ActiveEntity.Affiliations],
            },
        });
        const inactiveAffiliation = result.data.find((a) => a.validFrom > new Date() || (a.validTo && a.validTo < new Date()));
        assert.isDefined(inactiveAffiliation);
    }));
    it("options - do not include inactive entities", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.affiliations.find();
        const inactiveAffiliation = result.data.find((a) => a.validFrom > new Date() || (a.validTo && a.validTo < new Date()));
        assert.isUndefined(inactiveAffiliation);
    }));
    it("options - include inactive by default with correct client", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield clientWithInactiveEntities.affiliations.find();
        const inactiveAffiliation = result.data.find((a) => a.validFrom > new Date() || (a.validTo && a.validTo < new Date()));
        assert.isDefined(inactiveAffiliation);
    }));
    it("options - include persons without church affiliation with correct client", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield clientWithInactiveEntities.persons.get(personInactiveUid);
        assert.isDefined(result);
        assert.equal(result.data.uid, personInactiveUid);
    }));
}));

==> bcc-core-api-node-sdk-1.12.0.tgz: package/lib/esm/test/querying.js <==
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { assert } from "chai";
import { Affiliation, CoreApiClient, WrappedWithMetaArrayPerson, } from "../api.js";
import { ActiveEntity, serializeFindQueryParams, } from "../model/queryParams.js";
import { client, getDefaultConfig, person1Uid, personInactiveUid, } from "./helpers.js";
describe("Querying", () => __awaiter(void 0, void 0, void 0, function* () {
    let allPersons;
    let clientWithInactiveEntities;
    before(() => __awaiter(void 0, void 0, void 0, function* () {
        allPersons = (yield client.persons.find()).data;
        const defaultConfig = getDefaultConfig();
        defaultConfig.queryOptions = {
            includeInactive: [ActiveEntity.Affiliations, ActiveEntity.Consents],
            includePersonsWithoutChurchAffiliation: true,
        };
        clientWithInactiveEntities = new CoreApiClient(defaultConfig);
    }));
    beforeEach(() => __awaiter(void 0, void 0, void 0, function* () {
        yield client.refreshTestData();
    }));
    it("serializeFindQueryParams", () => __awaiter(void 0, void 0, void 0, function* () {
        const params = serializeFindQueryParams({
            sort: [
                {
                    direction: "ascending",
                    path: "firstName",
                },
                "-lastName",
            ],
        });
        assert.equal(params.get("sort"), "firstName,-lastName");
    }));
    it("sorting", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            sort: [
                {
                    direction: "ascending",
                    path: "displayName",
                },
            ],
            limit: 2,
            offset: 1,
        });
        assert.equal(result.meta.total, allPersons.length);
        assert.equal(result.meta.skipped, 1);
        assert.equal(result.meta.limit, 2);
        assert.instanceOf(result, WrappedWithMetaArrayPerson);
        const sortedPersons = allPersons.sort((a, b) => a.displayName > b.displayName ? 1 : -1);
        assert.equal(result.data[0].uid, sortedPersons[1].uid);
        assert.equal(result.data[1].uid, sortedPersons[2].uid);
    }));
    it("filtering", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            filter: {
                displayName: {
                    _gte: "Philly Daly",
                },
            },
        });
        const expectedResult = allPersons.filter((p) => p.displayName >= "Philly Daly");
        assert.equal(result.meta.total, expectedResult.length);
    }));
    it("filtering nested", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            filter: {
                affiliations: {
                    person: {
                        displayName: {
                            _eq: "Philly Daly",
                        },
                    },
                },
            },
        });
        const expectedResult = allPersons.filter((p) => p.displayName >= "Philly Daly");
        assert.equal(result.meta.total, expectedResult.length);
    }));
    it("search - find persons using a fuzzy search", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            search: "Philli dali",
        });
        assert.isDefined(result);
        assert.lengthOf(result.data, 1);
        assert.equal(result.data[0].uid, person1Uid);
    }));
    it("resolving", () => __awaiter(void 0, void 0, void 0, function* () {
        var _a;
        const result = yield client.persons.find({
            fields: ["*", "affiliations.*"],
        });
        assert.instanceOf((_a = result.data[0].affiliations) === null || _a === void 0 ? void 0 : _a[0], Affiliation);
    }));
    it("options - include persons without church affiliation", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            options: {
                includePersonsWithoutChurchAffiliation: true,
            },
        });
        const resultUids = result.data.map((r) => r.uid);
        assert.include(resultUids, personInactiveUid);
    }));
    it("options - do not include persons without church affiliation", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.persons.find({
            options: {
                includePersonsWithoutChurchAffiliation: false,
            },
        });
        const resultUids = result.data.map((r) => r.uid);
        assert.notInclude(resultUids, personInactiveUid);
    }));
    it("options - include inactive entities", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.affiliations.find({
            options: {
                includeInactive: [ActiveEntity.Affiliations],
            },
        });
        const inactiveAffiliation = result.data.find((a) => a.validFrom > new Date() || (a.validTo && a.validTo < new Date()));
        assert.isDefined(inactiveAffiliation);
    }));
    it("options - do not include inactive entities", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield client.affiliations.find();
        const inactiveAffiliation = result.data.find((a) => a.validFrom > new Date() || (a.validTo && a.validTo < new Date()));
        assert.isUndefined(inactiveAffiliation);
    }));
    it("options - include inactive by default with correct client", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield clientWithInactiveEntities.affiliations.find();
        const inactiveAffiliation = result.data.find((a) => a.validFrom > new Date() || (a.validTo && a.validTo < new Date()));
        assert.isDefined(inactiveAffiliation);
    }));
    it("options - include persons without church affiliation with correct client", () => __awaiter(void 0, void 0, void 0, function* () {
        const result = yield clientWithInactiveEntities.persons.get(personInactiveUid);
        assert.isDefined(result);
        assert.equal(result.data.uid, personInactiveUid);
    }));
}));
